yt.geometry.selection\_routines module
======================================

.. automodule:: yt.geometry.selection_routines
   :members:
   :undoc-members:
   :inherited-members:
   :show-inheritance:
